@@ -70,7 +70,7 @@ vaul_parser_options parser_options;
 /* The default working library. Can be overwritten with the
    -l command line option.
 */
-char *libname = ".";
+const char *libname = ".";
 
 struct mypool : vaul_pool {
   vaul_design_unit *get (char *library, char *name);
@@ -227,7 +227,7 @@ main (int argc, char *argv[])
     init_v2c_chunk ();
 
     bool success = true;
-    vaul.begin_session (libname);
+    vaul.begin_session ((char*)libname);
     while (optind < argc)
       {
 	success = emit (&vaul, argv[optind]) && success;
@@ -456,7 +456,7 @@ void emit_noqual_id (pIIR_Declaration);
    are decorated to make them unique, but only if we are verbose.
 */
 void
-emit_qual_id (pIIR_Declaration d, char *qual)
+emit_qual_id (pIIR_Declaration d, const char *qual)
 {
   if (d->is (IR_LIBRARY_UNIT))
     emit_id (pIIR_LibraryUnit(d)->library_name);
@@ -1319,21 +1319,21 @@ char *map_bin_op(char *id)
 	char *op = vaul_xstrdup(id+1);
 	op[strlen(op)-1] = '\0';
 	if(!strcmp(op, "="))
-	    op = "==";
+	    op = (char*)"==";
 	else if(!strcmp(op, ":="))
-	    op = "=";
+	    op = (char*)"=";
 	else if(!strcmp(op, "/="))
-	    op = "!=";
+	    op = (char*)"!=";
 	else if(!strcmp(op, "mod"))
-	    op = "%";
+	    op = (char*)"%";
 	else if(!strcmp(op, "or"))
-	    op = "||";
+	    op = (char*)"||";
 	else if(!strcmp(op, "and"))
-	    op = "&&";
+	    op = (char*)"&&";
 	else if(!strcmp(op, "xor"))
-	    op = "^";
+	    op = (char*)"^";
 	else if(!strcmp(op, "&"))
-	    op = " concat ";
+	    op = (char*)" concat ";
 	return op;
     } else
 	return NULL;
@@ -1347,7 +1347,7 @@ char *map_un_op(char *id)
 	char *op = vaul_xstrdup(id+1);
 	op[strlen(op)-1] = '\0';
 	if(!strcmp("not", op))
-	    op = "!";
+	    op = (char*)"!";
 	return op;
     } else
 	return NULL;
