@@ -20,6 +20,7 @@ struct timeval {
 };
 #endif
 
+#ifndef HAVE_GETTIMEOFDAY
 struct timezone {
   int tz_minuteswest; /* minutes W of Greenwich */
   int tz_dsttime;     /* type of dst correction */
@@ -52,6 +53,7 @@ inline int gettimeofday (struct timeval * tv, struct timezone * tz) {
   }
   return 0;
 }
+#endif /* HAVE_GETTIMEOFDAY */
 
 #else  /* _WIN32 */
 
