@@ -340,7 +340,7 @@ tree_base (tree_kind kind)
   return kind->base;
 }
 
-char*
+const char*
 tree_kind_name (tree_kind kind)
 {
   return kind->name;
@@ -358,10 +358,10 @@ spaces (int l)
   return "                              " + (30-l);
 }
 
-static void tree_print_1 (char *label, tree_base_node *n, int l, int max_l);
+static void tree_print_1 (const char *label, tree_base_node *n, int l, int max_l);
 
 static void
-tree_print_ctype (char *label, void *mem, int l, tree_ctype_info *info)
+tree_print_ctype (const char *label, void *mem, int l, tree_ctype_info *info)
 {
   printf ("%s%s (%s):\n%s", spaces(2*l), label, info->name, spaces(2*l+2));
   if (info->print)
@@ -393,7 +393,7 @@ tree_print_children (tree_base_node *n, tree_kind k, int l, int max_l)
 }
 
 static void
-tree_print_1 (char *label, tree_base_node *n, int l, int max_l)
+tree_print_1 (const char *label, tree_base_node *n, int l, int max_l)
 {
   if (l < max_l)
     {
@@ -410,7 +410,7 @@ tree_print_1 (char *label, tree_base_node *n, int l, int max_l)
 }
 
 void
-tree_print (char *label, tree_base_node *n, int levels)
+tree_print (const char *label, tree_base_node *n, int levels)
 {
   tree_print_1 (label, n, 0, levels);
 }
@@ -445,7 +445,7 @@ tree_find_mtab (tree_chunk_tab *ctab, int n_chunks, tree_kind *kind)
 }
 
 void
-tree_no_method (char *genfunc, tree_kind k)
+tree_no_method (const char *genfunc, tree_kind k)
 {
   fprintf (stderr, "generic function `%s' undefined for node kind %s.\n",
 	   genfunc, tree_kind_name (k));
@@ -453,7 +453,7 @@ tree_no_method (char *genfunc, tree_kind k)
 }
 
 void
-tree_conflicting_methods (char *genfunc, tree_kind k)
+tree_conflicting_methods (const char *genfunc, tree_kind k)
 {
   fprintf (stderr, "conflicting methods for generic function `%s'"
 	   " and node kind %s.\n", genfunc, tree_kind_name (k));
