@@ -115,7 +115,7 @@ L4ieee_Q16std_logic_signed_init_done=true;
 L3std_Q8standard_init ();
 L4ieee_Q15std_logic_arith_init ();
 L4ieee_Q14std_logic_1164_init ();
-register_source_file("/home/stefan/cvs/freehdl/ieee/std_logic_signed.vhdl","std_logic_signed.vhdl");
+register_source_file("/home/stefan/cvs-local/freehdl-teaser/ieee/std_logic_signed.vhdl","std_logic_signed.vhdl");
 name_stack iname;
 iname.push("");
 void *sref=register_package(":ieee",":std_logic_signed");
@@ -530,7 +530,7 @@ L4ieee_Q16std_logic_signed_init ();
 L3std_Q8standard_init ();
 L4ieee_Q15std_logic_arith_init ();
 L4ieee_Q14std_logic_1164_init ();
-register_source_file("/home/stefan/cvs/freehdl/ieee/std_logic_signed.vhdl","std_logic_signed.vhdl");
+register_source_file("/home/stefan/cvs-local/freehdl-teaser/ieee/std_logic_signed.vhdl","std_logic_signed.vhdl");
 name_stack iname;
 iname.push("");
 void *sref=register_package_body(":ieee",":std_logic_signed");
