@@ -562,7 +562,7 @@ kernel_class::setup_wait_info(const sigacl_list &salist, process_base *proc)
 // Init a generic value
 void 
 kernel_class::init_generic(void *generic, type_info_interface *info, name_stack &iname, 
-			   char *n, char *sln, map_list *mlist, const void *default_value,
+			   const char *n, const char *sln, map_list *mlist, const void *default_value,
 			   void *sr)
 {
   // Get generic parameter value
