@@ -1,6 +1,9 @@
 #if HAVE_ALLOCA_H
 #include <alloca.h>
 #endif
+#if HAVE_MALLOC_H
+#include <malloc.h>
+#endif
 #include <sstream>
 #include <freehdl/std-vhdl-types.hh>
 #include <freehdl/std-standard.hh>
