@@ -101,7 +101,7 @@ L3std_Q8standard_init()
   L3std_Q8standard_init_done = true;
 
   // Savely initialize the 'mem_chunks' memory
-  memset (mem_chunks, sizeof(void*)*(MAX_INTERNAL_ALLOC_SIZE+1),0);
+  memset (mem_chunks, 0, sizeof(void*)*(MAX_INTERNAL_ALLOC_SIZE+1));
 
   Xinfo_data_descriptor_init ();
   L3std_Q8standard_I9character_INFO.register_type(":std:standard",":std:standard:character", ":character", NULL);
@@ -184,7 +184,7 @@ report(const vstring &s, severity_level l)
 void 
 report(severity_level l)
 {
-  char *str = "";
+  const char *str = "";
   internal_report (str, l);
 }
 
