@@ -977,7 +977,7 @@ m_emit_hdr (pIIR_ProcessStatement p, string &str, RegionStack &rstack, int l)
   // process
   // *****************************************************************************
   bool first = true;
-  char *sep = " ";
+  const char *sep = " ";
   // first, get a list of driven signals
   access_list driven_sigs = 
     filter_unique(pctxt.accessed_objects, WRITE, 
