@@ -132,7 +132,7 @@ vector<string>
 get_library_and_unit_name(pIIR_Declaration decl);
 
 /* Get source file name associated with a node */
-char *
+const char *
 get_source_file_name(pIIR_Root n);
 
 /* Get id_type from region stack. Note that dependent on the region
