@@ -560,7 +560,7 @@ int
 main (int argc, char *argv[])
 {
   int opt, option_index;
-  char *libname = "work";
+  const char *libname = "work";
   char *generated_cc_file_name = NULL;
   char *main_cc_file_name = NULL;
   
@@ -643,7 +643,7 @@ main (int argc, char *argv[])
     fprintf (vaul.dependencies_file, "%s:", generated_cc_file_name);
 
   bool success = true;
-  vaul.begin_session (libname);
+  vaul.begin_session ((char*)libname);
   string str, cdfg_str, main_cc_str;
   vector<string> source_file_names; // Stores vhdl source files names
   emit_includes (str);					// #includes for sim
