@@ -409,7 +409,7 @@ pIIR_ArchitectureDeclaration
 psr::get_architecture (pIIR_EntityDeclaration entity,
 		       pIIR_TextLiteral arch)
 {
-  pIIR_ArchitectureDeclaration arch_decl;
+  pIIR_ArchitectureDeclaration arch_decl = NULL;
 
   vaul_design_unit *du = 
     pool->get_architecture (entity->library_name->text.to_chars (),
