@@ -23,7 +23,7 @@
 
 #include <freehdl/vaul-dfile.h>
 
-vaul_design_file::vaul_design_file (char *fn, FILE *f,
+vaul_design_file::vaul_design_file (const char *fn, FILE *f,
 				    vaul_parser_options &options)
   : lexer(fn, f),
     parser(&lexer)
