@@ -85,7 +85,7 @@ psr::build_TypeConversion (pIIR_PosInfo pos,
   return mIIR_TypeConversion(pos, t, t, e);
 }
 
-pIIR_Expression psr::build_bcall(pIIR_Expression l, char *op, pIIR_Expression r)
+pIIR_Expression psr::build_bcall(pIIR_Expression l, const char *op, pIIR_Expression r)
 {
   // XXX - reincarnate lno parm.
 
@@ -939,7 +939,7 @@ psr::try_array_subscription (pIIR_ArrayType at, pVAUL_GenAssocElem a)
   return cost;
 }
 
-static char *
+static const char *
 mode_name (IR_Mode m)
 {
   switch (m)
@@ -1391,7 +1391,7 @@ psr::associate_ports (pVAUL_NamedAssocElem actuals,
 	  if (obj)
 	    {
 	      IR_Mode peer_mode = vaul_get_mode (obj);
-	      char *allowed = NULL;
+	      const char *allowed = NULL;
 	      switch (p->mode)
 		{
 		case IR_IN_MODE:
@@ -2322,7 +2322,7 @@ bool psr::try_overload_resolution(pIIR_Expression e, pIIR_Type t, IR_Kind k)
     return constrain(e, t, k) >= 0;
 }
 
-static char *type_string(IR_Kind k)
+static const char *type_string(IR_Kind k)
 {
   if (k == IR_INTEGER_TYPE)
     return "an integer";
@@ -2806,7 +2806,7 @@ psr::overload_resolution (pIIR_Expression &e, pIIR_Type t, IR_Kind k,
 void
 psr::check_static_level (pIIR_Expression e, IR_StaticLevel l)
 {
-  static char *level_name[] = { "not(?)", "globally", "locally" };
+  static const char *level_name[] = { "not(?)", "globally", "locally" };
 
   // XXX - turn this into an error when the determination of the
   // static level of expressions is complete.
