@@ -732,6 +732,17 @@ psr::build_CaseStat (pIIR_PosInfo pos, pIIR_Expression swex,
       return NULL;
     }
 
+  if (swex->subtype->declaration == NULL)
+    {
+      swex_type = get_type(mVAUL_SimpleName(pos, make_id("integer")));
+      //pVAUL_SelName sn = mVAUL_SelName(pos, mVAUL_SimpleName(pos, make_id("std")),
+      //			       make_id("standard"));
+      //pIIR_Declaration spack = find_single_decl (sn, VAUL_STANDARD_PACKAGE, "(the) standard package");
+      //vaul_decl_set ds(this);
+      //find_decls (ds, mVAUL_SimpleName(pos, make_id("integer")), spack, true);
+      swex->subtype = swex_type;
+    }
+
   delete swex_types;
 
   overload_resolution (swex, swex_type);
